@@ -2,37 +2,42 @@
 #define GNUMERIC_PANE_H
 
 #include "gui-gnumeric.h"
-#include <libgnomecanvas/gnome-canvas-util.h>
+#include <libfoocanvas/foo-canvas.h>
+#include <libfoocanvas/foo-canvas-util.h>
+#include "gui-util.h"
 
 struct _GnumericPane {
 	int		 index;
-	GnumericCanvas	*gcanvas;
+	gboolean	 is_active;
+	GnmCanvas	*gcanvas;
 	struct {
-		GnomeCanvas *canvas;
-		ItemBar     *item;
+		FooCanvas *canvas;
+		ItemBar   *item;
 	} col, row;
 
 	/* Lines for resizing cols and rows */
 	struct {
-		GtkObject         *guide;
-		GtkObject         *start;
-		GnomeCanvasPoints *points;
+		GtkObject       *guide;
+		GtkObject       *start;
+		FooCanvasPoints *points;
 	} colrow_resize;
 
 	ItemGrid      *grid;
 	ItemEdit      *editor;
 
 	struct {
-		ItemCursor *std, *rangesel, *special;
+		ItemCursor *std, *rangesel, *special, *rangehighlight;
 	} cursor;
 	GSList		*anted_cursors;
 
-	SheetObject	 *drag_object;
-	GnomeCanvasItem  *control_points [9]; /* Control points for the current item */
+	SheetObject	*drag_object;
+	FooCanvasItem   *control_points [9]; /* Control points for the current item */
+
+	GdkCursor	*mouse_cursor;
 };
 
 void gnm_pane_init	(GnumericPane *pane, SheetControlGUI *scg,
-			 gboolean headers, int index);
+			 gboolean col_header, gboolean row_header, int index);
 void gnm_pane_release	(GnumericPane *pane);
 void gnm_pane_bound_set	(GnumericPane *pane,
 			 int start_col, int start_row,
@@ -48,17 +53,18 @@ void gnm_pane_colrow_resize_move	(GnumericPane *pane,
 					 gboolean is_cols, int resize_pos);
 
 void gnm_pane_reposition_cursors		(GnumericPane *pane);
-gboolean gnm_pane_cursor_bound_set	 	(GnumericPane *pane, Range const *r);
-gboolean gnm_pane_rangesel_bound_set		(GnumericPane *pane, Range const *r);
-void gnm_pane_rangesel_start			(GnumericPane *pane, Range const *r);
+gboolean gnm_pane_cursor_bound_set	 	(GnumericPane *pane, GnmRange const *r);
+gboolean gnm_pane_rangesel_bound_set		(GnumericPane *pane, GnmRange const *r);
+void gnm_pane_rangesel_start			(GnumericPane *pane, GnmRange const *r);
 void gnm_pane_rangesel_stop			(GnumericPane *pane);
-gboolean gnm_pane_special_cursor_bound_set	(GnumericPane *pane, Range const *r);
+gboolean gnm_pane_special_cursor_bound_set	(GnumericPane *pane, GnmRange const *r);
 void gnm_pane_special_cursor_start 		(GnumericPane *pane, int style, int button);
 void gnm_pane_special_cursor_stop		(GnumericPane *pane);
+void gnm_pane_mouse_cursor_set                  (GnumericPane *pane, GdkCursor *c);
 
-void gnm_pane_object_register	  (SheetObject *so, GnomeCanvasItem *view);
+void gnm_pane_object_register	  (SheetObject *so, FooCanvasItem *view);
 void gnm_pane_widget_register	  (SheetObject *so, GtkWidget *widget,
-				   GnomeCanvasItem *view);
+				   FooCanvasItem *view);
 void gnm_pane_object_stop_editing (GnumericPane *pane);
 void gnm_pane_object_set_bounds   (GnumericPane *pane, SheetObject *so,
 				   double l, double t, double r, double b);
