@@ -2,18 +2,16 @@
 #define GUI_GNUMERIC_H
 
 #include "gnumeric.h"
-#include <libgnomeui/libgnomeui.h>
 
 typedef struct _ItemCursor		ItemCursor;
 typedef struct _ItemGrid		ItemGrid;
 typedef struct _ItemBar			ItemBar;
 typedef struct _ItemEdit		ItemEdit;
-typedef struct _GnumericCanvas		GnumericCanvas;
+typedef struct _GnmCanvas		GnmCanvas;
 typedef struct _GnumericPane		GnumericPane;
 typedef struct _SheetControlGUI		SheetControlGUI;
-typedef struct _WorkbookControlGUI	WorkbookControlGUI;
+typedef struct _WorkbookControlComponent  WorkbookControlComponent;
+typedef struct _WorkbookControlGUI	  WorkbookControlGUI;
+typedef struct _WorkbookControlStandalone WorkbookControlStandalone;
 
-typedef gboolean (*GnumericCanvasSlideHandler) (GnumericCanvas *gcanvas,
-						int col, int row,
-						gpointer user_data);
 #endif /* GUI_GNUMERIC_H */
