@@ -116,7 +116,7 @@ WBC_VIRTUAL_FULL (menu_state_sheet_count, menu_state.sheet_count,
 	(WorkbookControl *wbc), (wbc))
 
 WBC_VIRTUAL (paste_from_selection,
-	(WorkbookControl *wbc, PasteTarget const *pt), (wbc, pt))
+	(WorkbookControl *wbc, GnmPasteTarget const *pt), (wbc, pt))
 
 void
 wb_control_sheet_add (WorkbookControl *wbc, SheetView *sv)
@@ -221,7 +221,7 @@ wb_control_parse_and_jump (WorkbookControl *wbc, char const *text)
 	/* not an address, is it a name ? */
 	target = global_range_parse (sheet, text);
 	if (target == NULL) {
-		ParsePos pp;
+		GnmParsePos pp;
 		GnmNamedExpr *nexpr = expr_name_lookup (
 			parse_pos_init_sheet (&pp, sheet), text);
 
@@ -229,7 +229,7 @@ wb_control_parse_and_jump (WorkbookControl *wbc, char const *text)
 		if (nexpr == NULL || expr_name_is_placeholder (nexpr)) {
 			GnmRange const *r = selection_first_range (
 				wb_control_cur_sheet_view (wbc),
-				COMMAND_CONTEXT (wbc),
+				GNM_CMD_CONTEXT (wbc),
 				_("Define Name"));
 			if (r != NULL) {
 				GnmCellRef a, b;
@@ -250,7 +250,7 @@ wb_control_parse_and_jump (WorkbookControl *wbc, char const *text)
 		} else {
 			target = gnm_expr_get_range (nexpr->expr);
 			if (target == NULL) {
-				gnumeric_error_invalid (COMMAND_CONTEXT (wbc), _("Address"), text);
+				gnm_cmd_context_error_invalid (GNM_CMD_CONTEXT (wbc), _("Address"), text);
 				return FALSE;
 			}
 		}
@@ -272,7 +272,7 @@ wb_control_parse_and_jump (WorkbookControl *wbc, char const *text)
 }
 
 static void
-cb_wbc_clipboard_modified (GnumericApplication *app, WorkbookControl *wbc)
+cb_wbc_clipboard_modified (GnmApp *app, WorkbookControl *wbc)
 {
 	wb_control_menu_state_update (wbc, MS_PASTE_SPECIAL);
 }
@@ -285,7 +285,7 @@ wbc_finalize (GObject *obj)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (obj);
 	if (wbc->clipboard_changed_signal)
-		g_signal_handler_disconnect (gnumeric_application_get_app (),
+		g_signal_handler_disconnect (gnm_app_get_app (),
 					     wbc->clipboard_changed_signal);
 	wbc->clipboard_changed_signal = 0;
 	if (wbc->wb_view != NULL)
@@ -307,14 +307,14 @@ workbook_control_init (GObject *obj)
 	WorkbookControl *wbc = WORKBOOK_CONTROL (obj);
 
 	wbc->clipboard_changed_signal = g_signal_connect (
-		gnumeric_application_get_app (),
+		gnm_app_get_app (),
 		"clipboard_modified",
 		G_CALLBACK (cb_wbc_clipboard_modified), wbc);
 }
 
 GSF_CLASS (WorkbookControl, workbook_control,
 	   workbook_control_class_init, workbook_control_init,
-	   COMMAND_CONTEXT_TYPE);
+	   GNM_CMD_CONTEXT_TYPE);
 
 void
 workbook_control_set_view (WorkbookControl *wbc,
